==> jc-1.4.0.tar.gz: java/awt/print/PrinterException.h <==
// public class java.awt.print.PrinterException

// class file dependencies
// @dep_class edcbe23a737fb84b java_awt_print_PrinterException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_awt_print_PrinterException_H_
#define _JC_java_awt_print_PrinterException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_print_PrinterException$sub_refs	_jc_java_awt_print_PrinterException$sub_refs;
typedef struct _jc_java_awt_print_PrinterException$sub_nonrefs	_jc_java_awt_print_PrinterException$sub_nonrefs;
typedef struct _jc_java_awt_print_PrinterException$refs	_jc_java_awt_print_PrinterException$refs;
typedef struct _jc_java_awt_print_PrinterException$nonrefs	_jc_java_awt_print_PrinterException$nonrefs;
typedef struct _jc_java_awt_print_PrinterException$object	_jc_java_awt_print_PrinterException$object;

typedef struct _jc_java_awt_print_PrinterException$fields_struct	_jc_java_awt_print_PrinterException$fields_struct;
typedef const struct _jc_java_awt_print_PrinterException$vmethods	_jc_java_awt_print_PrinterException$vmethods;
typedef const struct _jc_java_awt_print_PrinterException$vtable	_jc_java_awt_print_PrinterException$vtable;
typedef const struct _jc_java_awt_print_PrinterException$vtype	_jc_java_awt_print_PrinterException$vtype;

// Class fields structure
struct _jc_java_awt_print_PrinterException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_print_PrinterException$fields_struct _jc_java_awt_print_PrinterException$class_fields;

// Constructors
extern void _jc_java_awt_print_PrinterException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_print_PrinterException$object *);
extern void _jc_java_awt_print_PrinterException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_print_PrinterException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_awt_print_PrinterException$vmethods {
};

// Vtable
struct _jc_java_awt_print_PrinterException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_print_PrinterException$vmethods	java_awt_print_PrinterException;
};

// Vtype
struct _jc_java_awt_print_PrinterException$vtype {
	_jc_type			type;
	_jc_java_awt_print_PrinterException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_print_PrinterException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_print_PrinterException$refs {
    _jc_java_awt_print_PrinterException$sub_refs	java_awt_print_PrinterException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_print_PrinterException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_print_PrinterException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_print_PrinterException$sub_nonrefs	java_awt_print_PrinterException;
};

// Object instance structure
struct _jc_java_awt_print_PrinterException$object {
	_jc_java_awt_print_PrinterException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_print_PrinterException$vtype	*vtype;
	_jc_java_awt_print_PrinterException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_print_PrinterException$vtype _jc_java_awt_print_PrinterException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_print_PrinterException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_print_PrinterException$class_object;

#endif	/* _JC_java_awt_print_PrinterException_H_ */

==> jc-1.4.6.tar.gz: java/awt/print/PrinterException.h <==
// public class java.awt.print.PrinterException

// class file dependencies
// @dep_class edcbe23a737fb84b java_awt_print_PrinterException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_awt_print_PrinterException_H_
#define _JC_java_awt_print_PrinterException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_print_PrinterException$sub_refs	_jc_java_awt_print_PrinterException$sub_refs;
typedef struct _jc_java_awt_print_PrinterException$sub_nonrefs	_jc_java_awt_print_PrinterException$sub_nonrefs;
typedef struct _jc_java_awt_print_PrinterException$refs	_jc_java_awt_print_PrinterException$refs;
typedef struct _jc_java_awt_print_PrinterException$nonrefs	_jc_java_awt_print_PrinterException$nonrefs;
typedef struct _jc_java_awt_print_PrinterException$object	_jc_java_awt_print_PrinterException$object;

typedef struct _jc_java_awt_print_PrinterException$fields_struct	_jc_java_awt_print_PrinterException$fields_struct;
typedef const struct _jc_java_awt_print_PrinterException$vmethods	_jc_java_awt_print_PrinterException$vmethods;
typedef const struct _jc_java_awt_print_PrinterException$vtable	_jc_java_awt_print_PrinterException$vtable;
typedef const struct _jc_java_awt_print_PrinterException$vtype	_jc_java_awt_print_PrinterException$vtype;

// Class fields structure
struct _jc_java_awt_print_PrinterException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_print_PrinterException$fields_struct _jc_java_awt_print_PrinterException$class_fields;

// Constructors
extern void _jc_java_awt_print_PrinterException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_print_PrinterException$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_print_PrinterException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_print_PrinterException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_print_PrinterException$vmethods {
};

// Vtable
struct _jc_java_awt_print_PrinterException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_awt_print_PrinterException$vmethods	java_awt_print_PrinterException;
};

// Vtype
struct _jc_java_awt_print_PrinterException$vtype {
	_jc_type			type;
	_jc_java_awt_print_PrinterException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_print_PrinterException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_print_PrinterException$refs {
    _jc_java_awt_print_PrinterException$sub_refs	java_awt_print_PrinterException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_print_PrinterException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_print_PrinterException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_awt_print_PrinterException$sub_nonrefs	java_awt_print_PrinterException;
};

// Object instance structure
struct _jc_java_awt_print_PrinterException$object {
	_jc_java_awt_print_PrinterException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_print_PrinterException$vtype	*vtype;
	_jc_java_awt_print_PrinterException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_print_PrinterException$vtype _jc_java_awt_print_PrinterException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_print_PrinterException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_print_PrinterException$class_object;

#endif	/* _JC_java_awt_print_PrinterException_H_ */
